# PSYCH 4165 Lab 1
# command file for computing a repeated measures
# analysis of variance using lme() in R.
# Lewis O. Harvey, Jr.
# Department of Psychology
# University of Colorado
# 7 September 2010

# load the nlme library to use lme()
library(nlme)

# read in group data in wide format (from Excel text file)
fn <- file("lab_1_group_data_wide_Fall_2010.txt")
df.wide <- read.delim(fn, header=TRUE)

# ******************************************************
# reshape the file into long format
# Note: reshape() is a bit of a pain to use but what it does
# is take data that are in a so-called wide format
# (one row per subject, separate columns per dependent variable)
# and put it into the long formate needed by many R analysis routines
# (multiple rows per subject, single column per dependent variable)
df.long <- reshape(df.wide,
	varying = list(c("mu100","mu200"), c("sd100", "sd200"), c("aic100", "aic200")),
	idvar = "subject",
	times = c("100", "200"),
	v.names = c("mu", "sd", "aic"),
	timevar = "standard",
	direction = "long")
rownames(df.long) <- 1:dim(df.long)[1]
df.long$standard <- factor(df.long$standard) # make standard a factor
# ******************************************************

df <- df.long # use shorter name for the data frame

# ******************************************************
# Calculate Weber's Constant (k) for each subject and
# compute the log of Weber's constant
# Add both to the data frame
# Because "standard" was made into a factor for the anova,
# it has to be converted back into a number in order to use
# it (100 or 200) to divide into the JND
df <- cbind(df, Weber_k = df$sd / as.numeric(as.character((df$standard))))
df <- cbind(df, Log_k = log10(df$Weber_k))

# Write out a summary of the variables in the data frame:
summary(df)

# ******************************************************
# plotting section
# define two functions to plot the two sets of graphs
# plot1()
# plot2()
# ******************************************************

# Make a strip chart of Weber's k for each order
plot1 <- function() {
	# set graphic parameters to plot two graphs in one panel
	par(mfcol = c(2,1))
	with(df, stripchart(Weber_k ~ order,
		method = "jitter", jitter = 0.03,
		xlab = "Weber's k", 
		ylab = "Testing Order",
		main = "Strip Chart of Lab 1 Weber's k (Fall 2010)"))

	# Make a box plot of Weber's k for each order
	boxplot(Weber_k ~ order, data = df,
		horizontal = TRUE,
		ylab = "Testing Order",
		xlab = "Weber's k",
		main = "Box and Whisker Plot of Lab 1 Weber's k (Fall 2010)")
	par(mfcol = c(1,1))
}
# ******************************************************

# Make a strip chart of Weber's k for each standard
plot2 <- function() {
	# set graphic parameters to plot two graphs in one panel
	par(mfcol = c(2,1))
	with(df, stripchart(Weber_k ~ standard,
		method = "jitter", jitter = 0.03,
		xlab = "Weber's k", 
		ylab = "Standard Weight",
		main = "Strip Chart of Lab 1 Weber's k (Fall 2010)"))

	# Make a box plot of Weber's k for each standard
	boxplot(Weber_k ~ standard, data = df,
		horizontal = TRUE,
		ylab = "Standard Weight",
		xlab = "Weber's k",
		main = "Box and Whisker Plot of Lab 1 Weber's k (Fall 2010)")
	par(mfcol = c(1,1))
}
# ******************************************************

# compute the means
print(" ", quote = FALSE)
print("means", quote = FALSE)
print(with(df,tapply(Weber_k, order, "mean")))
print(with(df,tapply(Weber_k, standard, "mean")))

# use lme() to compute the ANOVA
print(" ", quote = FALSE)
print("Results of lme() Analysis Of Variance", quote = FALSE)

a <- lme(Weber_k ~ standard * order, data = df, random = ~ 1 | subject)
print(anova(a))
